package com.huguesjohnson;

import java.awt.Dimension;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.awt.Graphics;
import java.awt.Image;
import java.awt.image.CropImageFilter;
import java.awt.image.FilteredImageSource;
import java.awt.MediaTracker;
import java.awt.Toolkit;
import java.lang.InterruptedException;
import java.lang.String;
import javax.swing.JFrame;
import javax.swing.JPanel;

/** ImageCropDemo
* @author Hugues Johnson
*/
public class ImageCropDemo extends JFrame{
     /* constants */
     private final static String imagePath="c:\\image1.gif";
     
     /* shared members of class */
     private Image origImage;
     private Image cropImage;
     
     public ImageCropDemo(){
          /* load original image */
          this.origImage=Toolkit.getDefaultToolkit().getImage(this.imagePath);
          MediaTracker tracker=new MediaTracker(this);
          tracker.addImage(this.origImage,0);
          try{
               tracker.waitForID(0);
          } catch(InterruptedException ie){
               ie.printStackTrace();
          }

          /* load cropped image */
          /* find center of original image */
          int height=this.origImage.getHeight(this)/2;
          int width=this.origImage.getWidth(this)/2;
          int x=width/2;
          int y=height/2;
          /* create cropped image using CropImageFilter */
          this.cropImage=this.createImage(new FilteredImageSource(this.origImage.getSource(),new CropImageFilter(x,y,width,height)));
          tracker=new MediaTracker(this);
          tracker.addImage(this.cropImage,0);
          try{
               tracker.waitForID(0);
          } catch(InterruptedException ie){
               ie.printStackTrace();
          }
          
          /* create panel to hold window contents */
          Dimension panelSize=new Dimension(width*4,height*2);
          JPanel panel=new JPanel();
          panel.setMaximumSize(panelSize);
          panel.setMinimumSize(panelSize);
          panel.setPreferredSize(panelSize);
          panel.setSize(panelSize);
          this.getContentPane().add(panel);

          /* pack and show window */
          this.setResizable(true);
          this.pack();
          this.setVisible(true);
     }
     
     public void paint(Graphics g){
          if(this.origImage!=null){
               /* draw original image */
               g.drawImage(this.origImage,0,0,this);
               if(this.cropImage!=null){
                    /* draw crop image 10 pixels to the right of the original image */
                    g.drawImage(this.cropImage,this.origImage.getWidth(this)+10,0,this);
               }
          }
     }
     
     public static void main(String args[]){
          /* create window */
          ImageCropDemo window=new ImageCropDemo();
          /* override window closing event - terminate runtime when window is closed */
          window.addWindowListener(new WindowAdapter(){ public void windowClosing(WindowEvent e){System.exit(0);}});
     }
}
